.. musica documentation HTML titles
..
.. # (over and under) for module headings
.. = for sections
.. - for subsections
.. ^ for subsubsections
.. ~ for subsubsubsections
.. " for paragraphs

==================================
Welcome to MUSICA's documentation!
==================================

.. grid:: 1 1 2 2
    :gutter: 2

    .. grid-item-card:: Getting started
        :img-top: _static/index_getting_started.svg
        :link: getting_started/getting_started
        :link-type: doc

        Check out the getting started guide to build and install musica.

    .. grid-item-card::  User guide
        :img-top: _static/index_user_guide.svg
        :link: user_guide/index
        :link-type: doc

    .. grid-item-card::  API reference
        :img-top: _static/index_api.svg
        :link: api/index
        :link-type: doc

    .. grid-item-card::  Contributors guide
        :img-top: _static/index_contribute.svg
        :link: contributing/index
        :link-type: doc


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started/getting_started
   user_guide/index
   tutorial/tutorial
   api/index
   contributing/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
